/* Network app library  V1.0  15.8.1997	*/
/* copyright (c)1997 by Marek Zelem	*/ 
/* e-mail: marek@crazy.elf.stuba.sk	*/

#ifndef _NETAP_LIB_H
#define _NETAP_LIB_H

#ifndef _NET_LIB_H
#include <mmm/net_lib.h>
#endif _NET_LIB_H
#define	osockaddr	sockaddr
#include <protocols/talkd.h>

int netap_verlib(char *ver);
char *netap_uid2login( int uid );
int netap_login2uid( const char *loginname );
char *netap_username( void );

/* ---- Komplexne funkcie ---- */

/* netap_tell
 *	addr	- adresa vzdialeneho stroja
 *	port	- cislo portu, alebo 0 ak standardny
 *	fromname- meno odosielatela
 *	toname	- meno adresata
 *	text	- text spravy.
 *	out	- Pri vystupe nahradena textom odpovede. (max 1024)
 * RETURN VALUE
 *	0	- error - can't connect
 *	1	- o.k.
 */
int netap_tell(unsigned int addr, int port, char *fromname, char *toname, char *utty, char *text, char *out);

/* --- talk --- */

#define	MAX_INVITES	8

typedef struct {
		unsigned int	server_ip;
		int		server_port;
		long		id_num;
		unsigned int	sock_ip;
		int		sock_port;
		int		sock;
		time_t		time;
		unsigned int	announce_ip;
		int		announce_port;
		time_t		announce_time;
		long		announce_id_num;
		long		param;
		int(*func)(int,char*,long);
        	char		r_name[NAME_SIZE];	/* callee's name */
        	char		r_tty[TTY_SIZE];	/* callee's tty name */
	       }  talkinvite_t;

typedef struct {
		int		ctl_sock;
		unsigned int	ctl_ip;
		int		ctl_port;
		time_t		repeat_invite;
		time_t		repeat_announce;
		unsigned int	myserver_ip;
		int		myserver_port;
        	char		l_name[NAME_SIZE];	/* caller's name */
		talkinvite_t	invite[MAX_INVITES];
		int		invites;	/* pocet pozvani */
		struct sockaddr_in	sad;
		int		num;	/* ktory sa ma prijat */
		CTL_MSG		ctl_buf;
	       }  talk_t;

/* EXTERNE FUNKCIE:	netap_talk_open		netap_talk_close	*/
/*			netap_talk_talk		netap_talk_comm		*/

int netap_talk_open( talk_t *talk, unsigned int ip, int port, char *myname );
int netap_talk_close( talk_t *talk );

int netap_talk_i_new( talk_t *talk, char *r_name, char *r_tty );
int netap_talk_i_find( talk_t *talk, char *r_name, char *r_tty );
int netap_talk_i_del( talk_t *talk, int n );

/* netap_talk_invite   - interna funkcia na zaslanie invitation
 *   talk       - struktura talk, otvorena pomocou natap_talk_open
 *   ip         - nepovinna ip adresa ( ak 0 tak vyberie sam )
 *   port       - nepovinny port (ak 0 tak vyberie sam )
 *   toname     - meno volaneho
 *   to_tty     - tty volaneho
 * Return value - <0 ak error. num ak OK
 */
int netap_talk_invite( talk_t *talk, unsigned int ip, int port, char *toname, char *to_tty );

/* netap_talk_announce   - interna funkcia na zaslanie announce
 *   talk       - struktura talk, otvorena pomocou natap_talk_open
 *   num        - num of invitation
 *   ip         - nepovinna ip adresa ( ak 0 tak vyberie sam )
 *   port       - nepovinny port (ak 0 tak vyberie sam )
 * Return value - <0 ak error. num ak OK
 */
int netap_talk_announce( talk_t *talk, int num, unsigned int ip, int port );

/* netap_talk_lookup   - interna funkcia na zaslanie lookup
 *   type       - typ reqestu. (LOOK_UP, ANNOUNCE)
 *   talk       - struktura talk, otvorena pomocou natap_talk_open
 *   ip         - nepovinna ip adresa ( ak 0 tak vyberie sam )
 *   port       - nepovinny port (ak 0 tak vyberie sam )
 *   toname     - meno volaneho
 *   to_tty     - tty volaneho
 * Return value - <0 ak error. 0 alebo num ak OK
 * PRIKLADY POUZITIA:
 *   (LOOK_UP,talk,ip,0,toname,to_tty)          - <0 - err | 0 - OK
 *   (ANNOUNCE,talk,ip,0,toname,to_tty)         - <0 - err | 0 -OK
 */
int netap_talk_lookup( int type, talk_t *talk, unsigned int ip, int port, char *toname, char *to_tty );

/* netap_talk_request   - interna funkcia na zaslanie requestu
 *   type       - typ reqestu. (LOOK_UP, LEAVE_INVITE, DELETE, ANNOUNCE)
 *   talk       - struktura talk, otvorena pomocou natap_talk_open
 *   num        - pouzije ip a port, r_name a r_tty z invitation table[num]
 * Return value - <0 ak error. 0 alebo num ak OK
 * PRIKLADY POUZITIA:
 *   (LOOK_UP,talk,num)         - <0 - err | num - OK
 *   (LEAVE_INVITE,talk,num)    - <0 - err | num - OK ; opakovanie invitation
 *   (DELETE,talk,num)          - <0 - err | num - OK
 *   (ANNOUNCE,talk,num)        - <0 - err | num -OK
 */
int netap_talk_request( int type, talk_t *talk, int num );

/* netap_talk_receive   - interna funkcia na vyslanie prikazu a prijatie odpovede
 *   talk       - struktura talk, otvorena pomocou natap_talk_open
 *   ip         - nepovinny parameter ak answer=0 potom sem zapise ip z addr
 *   port       - nepovinny parameter ak answer=0 potom sem zapise port z addr
 * Return value:
 *   <0 error 0-ok 1-not here
 */
int netap_talk_receive( talk_t *talk, unsigned int *ip, int *port );

int netap_talk_talk( talk_t *talk, unsigned int ip, int port, char *toname, char *to_tty, int(*func)(int,char*,long), long param );
int netap_talk_comm( talk_t *talk, comm_t *tab, int n );

#endif _NETAP_LIB_H

